from typing import Literal

LLMProvider = Literal[
      "OpenAI",
      "Anthropic",
      "Google",
      "xAI",
      "Qwen",
      "Deepseek",
      "Mistral",
      "Cohere",
      "HuggingFace"
]